package com.example.venue_reservation_service.controller;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.example.venue_reservation_service.domain.Reservation;
import com.example.venue_reservation_service.dto.RAddDTO;
import com.example.venue_reservation_service.dto.ReservationDTO;
import com.example.venue_reservation_service.dto.SlotDTO;
import com.example.venue_reservation_service.service.ReservationService;
import com.example.venue_reservation_service.utils.DownExcel;
import com.example.venue_reservation_service.vo.Result;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import jakarta.annotation.Resource;
import jakarta.servlet.http.HttpServletResponse;
import org.apache.ibatis.annotations.Param;
import org.springframework.web.bind.annotation.*;

import javax.ws.rs.Path;
import java.io.IOException;

@RestController
@RequestMapping("/reservation")
@Api("预约操作管理")
@CrossOrigin
public class ReservationController {

    @Resource
    private ReservationService reservationService;

    @ApiOperation("添加预约信息")
    @PostMapping("/create")
    public Result create(@RequestBody RAddDTO dto){
        return reservationService.addReservation(dto);
    }

    @ApiOperation("查询预约订单信息")
    @PostMapping("/query")
    public Result query(@RequestBody ReservationDTO dto){
        return reservationService.getReservations(dto);
    }

    @ApiOperation("取消订单")
    @GetMapping("/cancel")
    public Result cancel(@RequestParam("reservationId") Integer reservationId){
        return reservationService.cancelReservation(reservationId);
    }

    @ApiOperation("对预约订单进行签到")
    @GetMapping("/signIn")
    public Result signIn(@RequestParam("reservationId") Integer reservationId){
        return reservationService.signInReservation(reservationId);
    }

    @ApiOperation("管理员查看详细的预约信息")
    @GetMapping("/detail")
    public Result detail(@RequestParam("reservationId") Integer id){
        return reservationService.queryDetail(id);
    }

    @ApiOperation("移除预约信息")
    @GetMapping("/remove")
    public Result remove(){
        return null;
    }

    @ApiOperation("获取预约数据")
    @GetMapping("/data")
    public Result data(@RequestParam("college") String college){
        return reservationService.queryData(college);
    }

    @ApiOperation("导出用户预约记录")
    @GetMapping("/excel/{id}")
    public void excel(@PathVariable("id") Integer userId, HttpServletResponse response){
        reservationService.exportExcel(response, userId);
    }

}
